@@ -2,11 +2,15 @@
 
 #' Axis guide with truncated line
 #'
+#' `r lifecycle::badge("questioning")`
 #' This axis guide is similar to the normal axis guides for position scales, but
 #' can shorten the axis line that is being drawn. The `guide_axis_colour()`
 #' function is the same but with different defaults for the truncation that do
 #' not truncate the axis. Axis truncation and recolouring is supported
 #' throughout axes in ggh4x.
+#' The function is questioned due to
+#' a possible migration of guide functions after ggplot2 releases a new guide
+#' system.
 #'
 #' @inheritParams ggplot2::guide_axis
 #' @param trunc_lower,trunc_upper The lower and upper range of the truncated
@@ -131,7 +135,34 @@ guide_axis_color <- guide_axis_colour
 #' @method guide_train axis_ggh4x
 guide_train.axis_ggh4x <- function(guide, scale, aesthetic = NULL) {
   aesthetic <- aesthetic %||% scale$aesthetics[1]
-  guide <- NextMethod()
+
+  breaks <- scale$get_breaks()
+
+  empty_ticks <- data_frame0(
+    !!aesthetic := numeric(0),
+    .value       = numeric(0),
+    .label       = character(0)
+  )
+
+  if (length(intersect(scale$aesthetics, guide$available_aes)) == 0) {
+    cli::cli_warn(c(
+      "Axis guide lacks appropriate scales.",
+      i = "Use one of {.or {.field {guide$available_aes}}}"
+    ))
+    guide$key <- empty_ticks
+  } else if (length(breaks) == 0) {
+    guide$key <- empty_ticks
+  } else {
+    mapped_breaks <- if (scale$is_discrete()) scale$map(breaks) else breaks
+    ticks <- data_frame0(!!aesthetic := mapped_breaks)
+    ticks$.value <- breaks
+    ticks$.label <- scale$get_labels(breaks)
+    guide$key <- ticks[is.finite(ticks[[aesthetic]]), ]
+  }
+
+  guide$name <- paste0(guide$name, "_", aesthetic)
+  guide$hash <- hash(list(guide$title, guide$key$.value,
+                          guide$key$.label, guide$name))
   guide <- truncate_guide(guide, scale, aesthetic)
   guide
 }
@@ -139,11 +170,32 @@ guide_train.axis_ggh4x <- function(guide, scale, aesthetic = NULL) {
 #' @export
 #' @method guide_transform axis_ggh4x
 guide_transform.axis_ggh4x <- function(guide, coord, panel_params) {
-  guide <- NextMethod()
+  if (is.null(guide$position) || nrow(guide$key) == 0) {
+    return(guide)
+  }
+
+  aesthetics <- names(guide$key)[!grepl("^\\.", names(guide$key))]
+
+  dual <- all(c("x", "y") %in% aesthetics)
+  if (!dual) {
+    other_aes <- setdiff(c("x", "y"), aesthetics)
+    override  <- if (guide$position %in% c("bottom", "left")) -Inf else Inf
+    guide$key[[other_aes]] <- override
+  }
+  guide$key <- coord$transform(guide$key, panel_params)
+  if (!dual) {
+    warn_for_guide_position(guide)
+  }
   guide$trunc <- transform_truncated(guide$trunc, coord, panel_params)
   return(guide)
 }
 
+#' @export
+#' @method guide_geom axis_ggh4x
+guide_geom.axis_ggh4x <- function(guide, ...) {
+  guide
+}
+
 #' @export
 #' @method guide_gengrob axis_ggh4x
 guide_gengrob.axis_ggh4x <- function(guide, theme) {
@@ -206,6 +258,12 @@ draw_axis_ggh4x <- function(
 }
 
 build_trunc_axis_line <- function(element, params, trunc) {
+  if (inherits(element, "element_blank")) {
+    return(zeroGrob())
+  }
+  if (is.null(trunc)) {
+    trunc <- data_frame(x = unit(0, "npc"), xend = unit(1, "npc"))
+  }
   pos <- unit.c(trunc[[1]], trunc[[2]])
   pos[c(TRUE, FALSE)] <- trunc[[1]]
   pos[c(FALSE, TRUE)] <- trunc[[2]]
@@ -217,6 +275,9 @@ build_trunc_axis_line <- function(element, params, trunc) {
 }
 
 transform_truncated <- function(trunc, coord, panel_params) {
+  if (is.null(trunc)) {
+    return(NULL)
+  }
   are_units <- c(is.unit(trunc[[1]]),
                  is.unit(trunc[[2]]))
   if (any(!are_units)) {
@@ -231,6 +292,9 @@ transform_truncated <- function(trunc, coord, panel_params) {
 }
 
 truncate_guide <- function(guide, scale, aesthetic) {
+  if (is.null(guide$trunc_lower) && is.null(guide$trunc_upper)) {
+    return(guide)
+  }
   trunc_lower <- axis_truncate(
     guide$key[[aesthetic]], guide$trunc_lower, scale, "lower"
   )
