@@ -197,7 +197,7 @@ test_that("scale_colour_multi sets labels independently", {
   guidenames <- vapply(guidebox, function(box) {
     box$grobs[box$layout$name == "title"][[1]]$children[[1]]$children[[1]]$label
   }, character(1))
-  i <- if (utils::packageVersion("ggplot2") <= "3.4.2") "label" else "labels"
+  i <- if (!new_guide_system) "label" else "labels"
   labs <- lapply(guidebox, function(tg){
     tg$grobs[tg$layout$name == i][[1]]$children[[1]]$label
   })[order(guidenames)]
