@@ -1,20 +1,3 @@
-test_that("try_require returns error when package is absent", {
-  expect_snapshot_error(try_require("nonsense", "test"))
-})
-
-test_that("try_require loads package namespace", {
-
-  unloadNamespace("fitdistrplus")
-  pkgs <- loadedNamespaces()
-  expect_false("fitdistrplus" %in% pkgs)
-  expect_false("package:fitdistrplus" %in% search())
-
-  try_require("fitdistrplus", "test")
-  pkgs <- loadedNamespaces()
-  expect_true("fitdistrplus" %in% pkgs)
-  expect_false("package:fitdistrplus" %in% search())
-})
-
 test_that("function grabber grabs functions", {
   x <- .grab_ggplot_internals()
   classes <- table(sapply(x, class))
